@@ -1,7 +1,8 @@
+#define QT_FEATURE_cross_compile -1
 #define QT_FEATURE_framework -1
 #define QT_FEATURE_rpath -1
-#define QT_FEATURE_accessibility 1
 #define QT_FEATURE_shared 1
+#define QT_FEATURE_appstore_compliant -1
 #define QT_FEATURE_debug_and_release -1
 #define QT_FEATURE_simulator_and_device -1
 #define QT_FEATURE_build_all -1
@@ -16,7 +17,7 @@
 #define QT_VISIBILITY_AVAILABLE true
 #define QT_FEATURE_separate_debug_info -1
 #define QT_FEATURE_static -1
-#define QT_VERSION_STR "5.8.0"
+#define QT_VERSION_STR "5.9.0"
 #define QT_VERSION_MAJOR 5
-#define QT_VERSION_MINOR 8
+#define QT_VERSION_MINOR 9
 #define QT_VERSION_PATCH 0
